extends Node2D

onready var collider = get_node("StaticBody2D/DoorCollider")
onready var player_detector = get_node("PlayerDetector")
onready var animation_player = get_node("AnimationPlayer")

var is_open = false
var is_destroyed = false

# these functions are called by the open/close animation
func close_door() -> void:
	collider.set_disabled(false)
	is_open = false

func open_door() -> void:
	collider.set_disabled(true)
	is_open = true

func blow_up() -> void:
	close_door()
	is_open = true
	animation_player.play("blow_up")

func set_destroyed() -> void:
	is_destroyed = true
	collider.set_disabled(true)

func repair() -> void:
	is_destroyed = false
	collider.set_disabled(false)

func player_interaction() -> void:
	if animation_player.is_playing():
		return

	if is_destroyed:
		animation_player.play("repair")
	elif is_open:
		animation_player.play("door_close")
	else:
		animation_player.play("door_open")

func player_is_interacting() -> bool:
	if Input.is_action_pressed("interact"):
		var overlapping_players =  player_detector.get_overlapping_bodies()
		for body in overlapping_players:
			# the player should be the only thing on layer 2
			if body.get_collision_layer_bit(2):
				return true
	return false

# Called every frame. 'delta' is the elapsed time since the previous frame.
func _physics_process(_delta: float) -> void:
	if player_is_interacting():
		player_interaction()
	elif is_destroyed:
		animation_player.stop(false) # false here means to not reset the playing animation
		pass
