extends Node

var Door = preload('res://scripts/Door.gd')
var current_scene = null
var has_started = false
var dim_timer
var intro_timer
var fail_timer
var test_timer
var stop_timer

# Called when the node enters the scene tree for the first time.
func _ready():
	   #On load set the current scene to the last scene available
	current_scene = get_tree().get_root().get_child(get_tree().get_root().get_child_count() -1)
	get_node("Player/Intro").play()
	intro_timer = get_node("IntroTimer")
	intro_timer.one_shot = true
	intro_timer.connect("timeout", self, "start_tests")
	intro_timer.start(39.0 + 1.0)
	
	stop_timer = get_node("StopTimer")
	stop_timer.one_shot = true
	stop_timer.connect("timeout", self, "stop_sound")
	stop_timer.start(39.0)

func stop_sound():
	get_node("Player/Intro").stop()
	get_node("Player/TestStart").stop()
	get_node("Player/Fail").stop()
	get_node("Player/FixIt").stop()

func start_tests(): 
	get_node("Player/TestStart").play()
	test_timer = get_node("TestTimer")
	test_timer.one_shot = true
	test_timer.connect("timeout", self, "start_scary")
	test_timer.start(9.38 + 1.0)
	stop_timer.start(9.38)

func _process(delta):
	var num_closed = 0
	var num_open = 0
	if has_started:
		for node in get_children():
			if node is Door:
				
				if node.is_open:
					num_open += 1
				else:
					num_closed += 1
		if num_open == 0:
			player_is_winner()

func player_is_winner():
	set_scene('res://scenes/Winner.tscn')

func start_scary():
	get_node('CanvasModulate').set_dark()
	get_node("Player/TestStart").stop()
	get_node("Player/Music").play()
		
	dim_timer = get_node("DimmerTimer")
	dim_timer.one_shot = true
	dim_timer.connect("timeout", self, "start")
	dim_timer.start(2)
	
	for node in get_children():
			if node is Door:
				node.blow_up()
	
	get_node("Player/Fail").play()
	fail_timer = get_node("FailTimer")
	fail_timer.one_shot = true
	fail_timer.connect("timeout", self, "start_fix")
	fail_timer.start(8.13 + 1.0)
	stop_timer.start(8.13)

func start_fix():
	get_node("Player/FixIt").play()
	stop_timer.start(20.96)

func start():
	has_started = true

func set_scene(new_scene: String):
	# Can be used like so:
	# get_node("/root/globals").setScene("res://game.scn")
	#clean up the current scene
	current_scene.queue_free()
	#load the file passed in as the param "scene"
	var s = ResourceLoader.load(new_scene)
	#create an instance of our scene
	current_scene = s.instance()
	# add scene to root
	get_tree().get_root().add_child(current_scene)

# Called every frame. 'delta' is the elapsed time since the previous frame.
#func _process(delta):
#	pass
